summaryrefslogtreecommitdiffstats
path: root/kmplot/kmplot/editfunction.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commiteb570158698cf61dad4f77d950ef908160f6c3cc (patch)
tree649bf182bcf0a20bed5035d25ffd77de5aee138a /kmplot/kmplot/editfunction.h
parentd8762de95349dc6edaa34db9bf699b367c1af6b1 (diff)
downloadtdeedu-eb570158698cf61dad4f77d950ef908160f6c3cc.tar.gz
tdeedu-eb570158698cf61dad4f77d950ef908160f6c3cc.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmplot/kmplot/editfunction.h')
-rw-r--r--kmplot/kmplot/editfunction.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmplot/kmplot/editfunction.h b/kmplot/kmplot/editfunction.h
index ef2613a1..51cf2186 100644
--- a/kmplot/kmplot/editfunction.h
+++ b/kmplot/kmplot/editfunction.h
@@ -42,9 +42,9 @@ class EditFunction : public KDialogBase
TQ_OBJECT
public:
/// @param parser points to the parser instance.
/// @param tqparent points to the tqparent widget.
/// @param name of this instance.
- EditFunction( XParser* parser, TQWidget* tqparent = NULL, const char* name = NULL );
+ EditFunction( XParser* parser, TQWidget* parent = NULL, const char* name = NULL );
/// Nothing special to do.
virtual ~EditFunction() {}
/// Fill the dialog's widgets with the properties of the parser function number index.
@@ -42,9 +42,9 @@ class EditFunction : public KDialogBase
public:
/// @param parser points to the parser instance.
- /// @param tqparent points to the tqparent widget.
+ /// @param parent points to the parent widget.
/// @param name of this instance.